@@ -31,7 +31,7 @@ class Extractor:
         self.custom_plugin_package = custom_plugin_package
         self.TLS = TLS
         
-    def extract(self):
+    def extract(self, append=False):
         plugins = self._plugins() if self.custom_plugin_package is None else self.custom_plugin_package
         
         # Sessions
@@ -54,9 +54,9 @@ class Extractor:
             sessions_df = session_streamer.to_pandas(columns_to_anonymize=[])
             config_filepath = path.join(path.dirname(__file__), 'tools/config.json')
             sessions_df = extract_tls_features_and_merge(sessions_df, self.input_pcap_filepath, config_filepath)
-            sessions_df.to_csv(path.join(self.output_dirpath,'out-sessions.csv'), index=False)
+            sessions_df.to_csv(path.join(self.output_dirpath,'out-sessions.csv'), index=False, mode='a' if append else 'w', header=not append)
         else:
-            session_streamer.to_csv(path.join(self.output_dirpath,'out-sessions.csv'))
+            session_streamer.to_csv(path.join(self.output_dirpath,'out-sessions.csv'), index=False, mode='a' if append else 'w', header=not append)
 
         # Hosts
         # HostsProcessor(sessions_df, self.output_dirpath).process()
